package cn.timer.api.config.exception;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import cn.hutool.core.util.StrUtil;
import cn.timer.api.utils.Result;
import cn.timer.api.utils.ResultUtil;

/**
 * 全局异常处理器
 * 
 * @author Tang
 */
@RestControllerAdvice // @ControllerAdvice + @ResponseBody 组合注解
public class GlobalExceptionHandler {

	private static final Logger log = LoggerFactory.getLogger(GlobalExceptionHandler.class);

	@ExceptionHandler(Exception.class)
	public Result<Object> handleException(Exception e) {
		log.error(e.getMessage(), e);
		return ResultUtil.error(e.getMessage());
	}

	/**
	 * 空指针异常
	 * @param e
	 * @return
	 */
	@ExceptionHandler(NullPointerException.class)
	public Result<Object> nullPointerException(NullPointerException e) {
		log.error(e.getMessage(), e);
		return ResultUtil.error(e.getMessage());
	}

	/**
	 * 类型强制转换异常
	 * @param e
	 * @return
	 */
	@ExceptionHandler(ClassCastException.class)
	public Result<Object> classCastException(ClassCastException e) {
		log.error(e.getMessage(), e);
		return ResultUtil.error(e.getMessage());
	}

	/**
	 * 业务异常
	 */
	@ExceptionHandler(CustomException.class)
	public Result<Object> businessException(CustomException e) {
		if (StrUtil.isBlank(e.getCode())) {
			return ResultUtil.error(e.getMessage());
		}
		return ResultUtil.error(e.getCode(), e.getMessage());
	}
}
